Range-v3: ranges::v3::concepts::IndirectlyProjectedMovable Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

All Classes Files Functions Variables Typedefs Friends Macros Modules Pages
Public Member Functions | List of all members
ranges::v3::concepts::IndirectlyProjectedMovable Struct Reference
Concepts

## Public Member Functions
template<typename I , typename P , typename O >
auto | requires_ (I i, P p, O o) -> decltype(concepts::valid_expr(concepts::model_of< Readable, I >(), concepts::model_of< RegularInvokable, P, Readable::reference_t< I >>(), concepts::model_of< SemiRegular, O >(), concepts::model_of< MoveWritable, O, Invokable::result_t< P, Readable::reference_t< I >>>()))